
#ifndef _C14_kl687_
#define _C14_kl687_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F216_2107(EIF_REFERENCE, EIF_NATURAL_32, EIF_NATURAL_32);
extern void EIF_Minit687(void);

#ifdef __cplusplus
}
#endif

#endif
